package com.localmatters;

import java.util.ArrayList;
import java.util.Enumeration;
import java.util.List;
import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageConsumer;
import javax.jms.Queue;
import javax.jms.QueueBrowser;
import javax.jms.Session;
import javax.naming.InitialContext;

/**
 *
 * @author Daniel Cavalcanti
 */
public class Browser {
    
    // **********************************************************************
    // Class constants
    // **********************************************************************
    
    public static final String MESSAGE_ID = "id";
    public static final String MESSAGE_CONTENT = "content";
    
    // **********************************************************************
    // Instance variables
    // **********************************************************************
    
    private InitialContext ic;
    private Connection connection;
    
    // User input fields ****************************************************
    
    private String filter;
    private List<String> ids = new ArrayList<String>();
    private String deleted;
    
    // **********************************************************************
    // Constructors
    // **********************************************************************
    
    /**
     * Creates a new instance of Browser.
     */
    public Browser() {
        
        
        try {
            ic = new InitialContext();
            ConnectionFactory connectionFactory = (ConnectionFactory) ic.lookup("jms/CollectorConnectionFactory");
            connection = connectionFactory.createConnection("guest", "guest");
        } catch (Throwable ex) {
            ex.printStackTrace();
        }
        
    }

    protected void finalize()
    throws Throwable {
        super.finalize();
        
        try {
            if (connection != null)
                connection.close();
        } catch (Throwable ex) {
            ex.printStackTrace();
        }
        
    }
    
    // **********************************************************************
    // Getter/Setter methods
    // **********************************************************************
    
    public List getIds() {
        return ids;
    }
    
    public String getFilter() {
        return filter;
    }
    
    public void setFilter(String filter) {
        this.filter = filter;
    }
    
    public String getDeleted() {
        return deleted;
    }
    
    // **********************************************************************
    // Action methods
    // **********************************************************************
    
    public String list() {
        
        Session session = null;
        ids = new ArrayList<String>();
        
        try {
            
            Queue queue = (Queue) ic.lookup("jms/RequestQueue");
            session = connection.createSession(true, Session.SESSION_TRANSACTED);
            QueueBrowser browser = (filter == null || filter.trim().length() == 0) ? session.createBrowser(queue) : session.createBrowser(queue, filter);
            
            for (Enumeration messages = browser.getEnumeration() ; messages.hasMoreElements() ; ) {
                Message message = (Message) messages.nextElement();
                ids.add(message.getJMSMessageID());
            }
            
        } catch (Throwable ex) {
            ex.printStackTrace();
        } finally {
            try {
                if (session != null) session.close();
            } catch (JMSException ex) {
                ex.printStackTrace();
            }
        }
        
        return null;
        
    }
    
    public String remove() {
        
        Session session = null;
        ids = new ArrayList<String>();
        
        try {
            
            Queue queue = (Queue) ic.lookup("jms/RequestQueue");
            session = connection.createSession(true, Session.SESSION_TRANSACTED);
            MessageConsumer consumer = (filter == null || filter.trim().length() == 0) ? session.createConsumer(queue) : session.createConsumer(queue, filter);
            
            Message message = consumer.receiveNoWait();
            if (message != null) deleted = message.getJMSMessageID();
            
        } catch (Throwable ex) {
            ex.printStackTrace();
        } finally {
            try {
                if (session != null) session.close();
            } catch (JMSException ex) {
                ex.printStackTrace();
            }
        }
        
        return null;
        
    }
    
    // **********************************************************************
    // Auxiliary methods
    // **********************************************************************

}
